@@ -16,10 +16,13 @@ module.exports = {
   ...base,
   name: 'dashboard-frontend',
   displayName: 'Dashboard Frontend',
+  moduleDirectories: ['node_modules', '../../node_modules', 'src'],
   moduleNameMapper: {
     '\\.(css|less|sass|scss|styl)$': '<rootDir>/__mocks__/styleMock.js',
     '\\.(gif|ttf|eot|svg)$': '<rootDir>/__mocks__/fileMock.js',
-    'monaco-editor-core': 'monaco-editor-core/esm/vs/editor/editor.main'
+    'monaco-editor-core': 'monaco-editor-core/esm/vs/editor/editor.main',
+      'vscode-languageserver-protocol/lib/utils/is': 'vscode-languageserver-protocol/lib/common/utils/is',
+    'vscode-languageserver-protocol/lib/main': 'vscode-languageserver-protocol/lib/node/main',
   },
   globals: {
     'ts-jest': {
