@@ -14,28 +14,35 @@ import { AlertActionLink, AlertVariant } from '@patternfly/react-core';
 import React from 'react';
 import { connect, ConnectedProps } from 'react-redux';
 import { History } from 'history';
+import common from '@eclipse-che/common';
 import { delay } from '../../services/helpers/delay';
 import { AppState } from '../../store';
 import * as FactoryResolverStore from '../../store/FactoryResolver';
 import * as WorkspaceStore from '../../store/Workspaces';
 import FactoryLoader from '../../pages/FactoryLoader';
-import { selectAllWorkspaces, selectWorkspaceById } from '../../store/Workspaces/selectors';
-import { selectPreferredStorageType } from '../../store/Workspaces/Settings/selectors';
+import {
+  selectAllWorkspaces,
+  selectWorkspaceById,
+  selectWorkspaceByQualifiedName
+} from '../../store/Workspaces/selectors';
+import { selectCheDevworkspaceEnabled, selectPreferredStorageType, selectWorkspacesSettings } from '../../store/Workspaces/Settings/selectors';
 import { buildIdeLoaderLocation, sanitizeLocation } from '../../services/helpers/location';
 import { lazyInject } from '../../inversify.config';
 import { KeycloakAuthService } from '../../services/keycloak/auth';
 import { getEnvironment, isDevEnvironment } from '../../services/helpers/environment';
 import { isOAuthResponse } from '../../store/FactoryResolver';
 import { updateDevfile } from '../../services/storageTypes';
-import { isDevfileV1, isWorkspaceV1, Workspace } from '../../services/workspaceAdapter';
+import { isCheDevfile, isCheWorkspace, Workspace } from '../../services/workspace-adapter';
 import { AlertOptions } from '../../pages/FactoryLoader';
-import { selectInfrastructureNamespaces } from '../../store/InfrastructureNamespaces/selectors';
+import { selectDefaultNamespace, selectInfrastructureNamespaces } from '../../store/InfrastructureNamespaces/selectors';
 import { safeLoad } from 'js-yaml';
 import updateDevfileMetadata, { FactorySource } from './updateDevfileMetadata';
-import { DEVWORKSPACE_DEVFILE_SOURCE } from '../../services/workspace-client/devWorkspaceClient';
-import { getErrorMessage } from '../../services/helpers/getErrorMessage';
+import { DEVWORKSPACE_DEVFILE_SOURCE } from '../../services/workspace-client/devworkspace/devWorkspaceClient';
+import devfileApi, { isDevfileV2 } from '../../services/devfileApi';
+import getRandomString from '../../services/helpers/random';
+import { DevfileConverter } from './devfile-converter';
 
-const WS_ATTRIBUTES_TO_SAVE: string[] = ['workspaceDeploymentLabels', 'workspaceDeploymentAnnotations', 'policies.create'];
+const WS_ATTRIBUTES_TO_SAVE: string[] = ['workspaceDeploymentLabels', 'workspaceDeploymentAnnotations', 'policies.create', 'che-editor'];
 
 const DEFAULT_CREATE_POLICY = 'perclick';
 
@@ -66,6 +73,7 @@ type State = {
   currentStep: LoadFactorySteps;
   hasError: boolean;
   createPolicy: CreatePolicy;
+  cheDevworkspaceEnabled: boolean;
 };
 
 export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
@@ -74,6 +82,7 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
   private overrideDevfileObject: {
     [params: string]: string
   } = {};
+  private converter: DevfileConverter;
 
   @lazyInject(KeycloakAuthService)
   private readonly keycloakAuthService: KeycloakAuthService;
@@ -82,13 +91,17 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
     super(props);
 
     const { search } = this.props.history.location;
+    const cheDevworkspaceEnabled = this.props.workspacesSettings['che.devworkspaces.enabled'] === 'true';
 
     this.state = {
       currentStep: LoadFactorySteps.INITIALIZING,
       hasError: false,
       createPolicy: DEFAULT_CREATE_POLICY,
       search,
+      cheDevworkspaceEnabled,
     };
+
+    this.converter = new DevfileConverter();
   }
 
   private resetOverrideParams(): void {
@@ -134,11 +147,21 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
     }
   }
 
+  private showOnlyContentIfDevWorkspace(): void {
+    if (this.state.cheDevworkspaceEnabled) {
+      // hide all bars
+      window.postMessage('hide-allbar', '*');
+    }
+  }
+
   public componentDidMount(): void {
+    this.showOnlyContentIfDevWorkspace();
     this.createWorkspaceFromFactory();
   }
 
   public async componentDidUpdate(): Promise<void> {
+    this.showOnlyContentIfDevWorkspace();
+
     const { history, workspace, factoryResolver } = this.props;
     if (this.state.search !== history.location.search) {
       this.setState({
@@ -267,7 +290,7 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
         this.resolvePrivateDevfile(e.attributes.oauth_authentication_url, location);
         return;
       }
-      this.showAlert('Failed to resolve a devfile. ' + getErrorMessage(e));
+      this.showAlert(`Failed to resolve a devfile. ${common.helpers.errors.getMessage(e)}`);
       return;
     }
     if (this.factoryResolver.resolver?.location !== location) {
@@ -276,22 +299,29 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
     }
     const { source } = this.factoryResolver.resolver;
     const searchParam = new window.URLSearchParams(this.state.search);
+    let devfile = this.getTargetDevfile();
     let resolvedDevfileMessage: string;
     // source tells where devfile comes from
     //  - no source: the url to raw content is used
     //  - repo: means no devfile is found and default is generated
     //  - any other - devfile is found in repository as filename from the value
     if (!source) {
-      resolvedDevfileMessage = `Devfile loaded from ${searchParam.get('url')}`;
+      resolvedDevfileMessage = `Devfile loaded from ${searchParam.get('url')}.`;
+    } else if (source === 'repo') {
+      resolvedDevfileMessage = `Devfile could not be found in ${searchParam.get(
+        'url',
+      )}. Applying the default configuration.`;
     } else {
-      if (source === 'repo') {
-        resolvedDevfileMessage = `Devfile could not be found in ${searchParam.get('url')}. Applying the default configuration`;
-      } else {
-        resolvedDevfileMessage = `Devfile found in repo ${searchParam.get('url')} as '${source}'. Applying it`;
-      }
+      resolvedDevfileMessage = `Devfile found in repo ${searchParam.get('url')} as '${source}'.`;
     }
+
+    if (this.props.cheDevworkspaceEnabled === false && isDevfileV2(devfile)) {
+      resolvedDevfileMessage += ' Devfile 2.x version found, converting it to devfile version 1.';
+      devfile = this.converter.devfileV2toDevfileV1(devfile);
+    }
+
     this.setState({ resolvedDevfileMessage });
-    return this.getTargetDevfile();
+    return devfile;
   }
 
   private resolvePrivateDevfile(oauthUrl: string, location: string): void {
@@ -347,12 +377,15 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
     return factoryParams;
   }
 
-  private async resolveWorkspace(devfile: api.che.workspace.devfile.Devfile, attrs: { [key: string]: string }): Promise<Workspace | undefined> {
+  private async resolveWorkspace(
+    devfile: api.che.workspace.devfile.Devfile | devfileApi.Devfile,
+    attrs: { [key: string]: string }
+  ): Promise<Workspace | undefined> {
     let workspace: Workspace | undefined;
     const stackName = this.getWorkspaceV1StackName(attrs.factoryParams);
     if (this.state.createPolicy === 'peruser') {
       workspace = this.props.allWorkspaces.find(workspace => {
-        if (isWorkspaceV1(workspace.ref)) {
+        if (isCheWorkspace(workspace.ref)) {
           return workspace.ref?.attributes?.stackName === stackName;
         }
         else {
@@ -369,12 +402,20 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
     }
     if (!workspace) {
       // for backward compatibility with workspaces V1
-      if (isDevfileV1(devfile)) {
+      if (isCheDevfile(devfile)) {
         attrs.stackName = stackName;
         delete attrs.factoryParams;
+        if (!devfile.metadata.name && devfile.metadata.generateName) {
+          const name = devfile.metadata.generateName + getRandomString(4).toLowerCase();
+          delete devfile.metadata.generateName;
+          devfile.metadata.name = name;
+        }
       }
+      const namespace = this.props.defaultNamespace?.name;
       try {
-        workspace = await this.props.createWorkspaceFromDevfile(devfile, undefined, undefined, attrs, this.factoryResolver.resolver.optionalFilesContent || {});
+        await this.props.createWorkspaceFromDevfile(devfile, undefined, namespace, attrs, this.factoryResolver.resolver.optionalFilesContent || {});
+        this.props.setWorkspaceQualifiedName(namespace, devfile.metadata.name as string);
+        workspace = this.props.activeWorkspace;
       } catch (e) {
         this.showAlert(`Failed to create a workspace. ${e}`);
         return;
@@ -386,7 +427,7 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
     }
     // check if it ephemeral
     // not implemented for dev workspaces yet
-    if (isWorkspaceV1(workspace.ref) && workspace.storageType === 'ephemeral') {
+    if (isCheWorkspace(workspace.ref) && workspace.storageType === 'ephemeral') {
       this.showAlert({
         title: 'You\'re starting an ephemeral workspace. All changes to the source code will be lost ' +
           'when the workspace is stopped unless they are pushed to a remote code repository.',
@@ -509,7 +550,12 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
 
   render() {
     const { workspace } = this.props;
-    const { currentStep, resolvedDevfileMessage, hasError } = this.state;
+    const {
+      currentStep,
+      resolvedDevfileMessage,
+      hasError,
+      cheDevworkspaceEnabled,
+    } = this.state;
     const workspaceName = workspace ? workspace.name : '';
     const workspaceId = workspace ? workspace.id : '';
 
@@ -520,6 +566,7 @@ export class FactoryLoaderContainer extends React.PureComponent<Props, State> {
         resolvedDevfileMessage={resolvedDevfileMessage}
         workspaceId={workspaceId}
         workspaceName={workspaceName}
+        isDevWorkspace={cheDevworkspaceEnabled}
         callbacks={this.factoryLoaderCallbacks}
       />
     );
@@ -533,6 +580,10 @@ const mapStateToProps = (state: AppState) => ({
   allWorkspaces: selectAllWorkspaces(state),
   infrastructureNamespaces: selectInfrastructureNamespaces(state),
   preferredStorageType: selectPreferredStorageType(state),
+  activeWorkspace: selectWorkspaceByQualifiedName(state),
+  defaultNamespace: selectDefaultNamespace(state),
+  workspacesSettings: selectWorkspacesSettings(state),
+  cheDevworkspaceEnabled: selectCheDevworkspaceEnabled(state),
 });
 
 const connector = connect(
