@@ -21,12 +21,14 @@ import { createFakeCheWorkspace } from '../../store/__mocks__/workspace';
 import { WorkspaceStatus } from '../../services/helpers/types';
 import FactoryLoaderContainer, { LoadFactorySteps } from '../FactoryLoader';
 import { AlertOptions } from '../../pages/IdeLoader';
-import { convertWorkspace, Workspace } from '../../services/workspaceAdapter';
+import { convertWorkspace, Workspace, WorkspaceAdapter } from '../../services/workspace-adapter';
 import { DevWorkspaceBuilder } from '../../store/__mocks__/devWorkspaceBuilder';
-import { IDevWorkspace } from '@eclipse-che/devworkspace-client';
+import devfileApi from '../../services/devfileApi';
 import { safeDump } from 'js-yaml';
+import { CheWorkspaceBuilder } from '../../store/__mocks__/cheWorkspaceBuilder';
 
 const showAlertMock = jest.fn();
+const setWorkspaceQualifiedName = jest.fn();
 const createWorkspaceFromDevfileMock = jest.fn().mockResolvedValue(undefined);
 const requestWorkspaceMock = jest.fn().mockResolvedValue(undefined);
 const startWorkspaceMock = jest.fn().mockResolvedValue(undefined);
@@ -46,7 +48,6 @@ jest.mock('../../store/Workspaces/index', () => {
       createWorkspaceFromDevfile: (devfile, namespace, infrastructureNamespace, attributes) =>
         async (): Promise<Workspace> => {
           createWorkspaceFromDevfileMock(devfile, namespace, infrastructureNamespace, attributes);
-          jest.runOnlyPendingTimers();
           return convertWorkspace({
             id: 'id-wksp-test',
             attributes,
@@ -62,6 +63,9 @@ jest.mock('../../store/Workspaces/index', () => {
       clearWorkspaceId: () => async (): Promise<void> => {
         clearWorkspaceIdMock();
       },
+      setWorkspaceQualifiedName: ( namespace: string, workspaceName: string) => async (): Promise<void> => {
+        setWorkspaceQualifiedName(namespace, workspaceName);
+      },
     },
   };
 });
@@ -106,6 +110,8 @@ jest.mock('../../pages/FactoryLoader', () => {
   };
 });
 
+const namespace = 'che';
+
 describe('Factory Loader container', () => {
 
   beforeEach(() => {
@@ -118,6 +124,188 @@ describe('Factory Loader container', () => {
     jest.useRealTimers();
   });
 
+  describe('converting devfiles', () => {
+    it('should NOT convert devfile v1 in Che Server mode', async () => {
+      const location = 'http://test-location';
+      const workspaceV1 = new CheWorkspaceBuilder()
+        .withId('my-workspace-id')
+        .withName('my-project')
+        .build();
+      const workspace = convertWorkspace(workspaceV1);
+
+      const store = new FakeStoreBuilder()
+        .withCheWorkspaces({
+          workspaces: [workspaceV1],
+        })
+        .withWorkspaces({
+          workspaceId: workspace.id,
+          namespace: workspace.namespace,
+          workspaceName: workspace.name,
+        })
+        .withWorkspacesSettings({
+          'che.devworkspaces.enabled': 'false',
+        } as che.WorkspaceSettings)
+        .withFactoryResolver({
+          v: '4.0',
+          source: 'devfile.yaml',
+          devfile: workspace.devfile,
+          location,
+          links: [],
+        })
+        .withInfrastructureNamespace([{ name: namespace, attributes: { phase: 'Active' } }], false)
+        .build();
+      const props = getMockRouterProps(ROUTE.LOAD_FACTORY_URL, { url: location });
+
+      render(
+        <Provider store={store}>
+          <FactoryLoaderContainer {...props} />
+        </Provider>,
+      );
+
+      await waitFor(() => expect(startWorkspaceMock).toHaveBeenCalled());
+
+      const convertingMessage = screen.queryByText(
+        'Devfile 2.x version found, converting it to devfile version 1.',
+        { exact: false },
+      );
+      // the message should not appear
+      expect(convertingMessage).toBeNull();
+
+      // the correct devfile should be passed
+      expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(
+        workspace.devfile,
+        undefined,
+        expect.anything(),
+        expect.anything(),
+      );
+    });
+
+    it('should convert devfile v2 to v1 in Che Server mode', async () => {
+      const location = 'http://test-location';
+      const workspaceV2 = new DevWorkspaceBuilder()
+        .withId('my-workspace-id')
+        .withName('my-project')
+        .build();
+      const workspace = convertWorkspace(workspaceV2);
+      const workspaceV1 = new CheWorkspaceBuilder()
+        .withId(workspace.id)
+        .withName(workspace.name)
+        .build();
+
+      const store = new FakeStoreBuilder()
+        .withCheWorkspaces({
+          workspaces: [workspaceV1],
+        })
+        .withWorkspaces({
+          workspaceId: workspace.id,
+          namespace: workspace.namespace,
+          workspaceName: workspace.name,
+        })
+        .withWorkspacesSettings({
+          'che.devworkspaces.enabled': 'false',
+        } as che.WorkspaceSettings)
+        .withFactoryResolver({
+          v: '4.0',
+          source: 'devfile.yaml',
+          devfile: workspace.devfile,
+          location,
+          links: [],
+        })
+        .withInfrastructureNamespace([{ name: namespace, attributes: { phase: 'Active' } }], false)
+        .build();
+      const props = getMockRouterProps(ROUTE.LOAD_FACTORY_URL, { url: location });
+
+      render(
+        <Provider store={store}>
+          <FactoryLoaderContainer {...props} />
+        </Provider>,
+      );
+
+      await waitFor(() => expect(startWorkspaceMock).toHaveBeenCalled());
+
+      const convertingMessage = screen.queryByText(
+        'Devfile 2.x version found, converting it to devfile version 1.',
+        { exact: false },
+      );
+      // the message should appear
+      expect(convertingMessage).not.toBeNull();
+
+      // the correct devfile should be passed
+      expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(
+        expect.objectContaining({
+          apiVersion: workspaceV1.devfile.apiVersion,
+          metadata: expect.objectContaining({
+            name: expect.stringMatching(workspaceV1.devfile.metadata.name as string),
+          }),
+        } as che.WorkspaceDevfile),
+        undefined,
+        expect.anything(),
+        expect.anything(),
+      );
+    });
+
+    it('should NOT convert devfile v2 in devworkspaces mode', async () => {
+      const location = 'http://test-location';
+      const workspaceV2 = new DevWorkspaceBuilder()
+        .withId('my-workspace-id')
+        .withName('my-project')
+        .build();
+      const workspace = convertWorkspace(workspaceV2);
+
+      const store = new FakeStoreBuilder()
+        .withDevWorkspaces({
+          workspaces: [workspaceV2],
+        })
+        .withWorkspaces({
+          workspaceId: workspace.id,
+          namespace: workspace.namespace,
+          workspaceName: workspace.name,
+        })
+        .withWorkspacesSettings({
+          'che.devworkspaces.enabled': 'true',
+        } as che.WorkspaceSettings)
+        .withFactoryResolver({
+          v: '4.0',
+          source: 'devfile.yaml',
+          devfile: workspace.devfile,
+          location,
+          links: [],
+        })
+        .withInfrastructureNamespace([{ name: namespace, attributes: { phase: 'Active' } }], false)
+        .build();
+      const props = getMockRouterProps(ROUTE.LOAD_FACTORY_URL, { url: location });
+
+      render(
+        <Provider store={store}>
+          <FactoryLoaderContainer {...props} />
+        </Provider>,
+      );
+
+      await waitFor(() => expect(startWorkspaceMock).toHaveBeenCalled());
+
+      const convertingMessage = screen.queryByText(
+        'Devfile 2.x version found, converting it to devfile version 1.',
+        { exact: false },
+      );
+      // the message should not appear
+      expect(convertingMessage).toBeNull();
+
+      // the correct devfile should be passed
+      const devfile = workspace.devfile as devfileApi.Devfile;
+      expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(
+        expect.objectContaining({
+          schemaVersion: devfile.schemaVersion,
+          metadata: expect.objectContaining({
+            name: expect.stringMatching(devfile.metadata.name),
+          }),
+        } as devfileApi.Devfile),
+        undefined,
+        expect.anything(),
+        expect.anything(),
+      );
+    });
+  });
+
   describe('Use a devfile V1', () => {
 
     it('should resolve the factory, create and start a new workspace', async () => {
@@ -138,7 +326,8 @@ describe('Factory Loader container', () => {
 
       jest.runOnlyPendingTimers();
       await waitFor(() =>
-        expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(workspace.devfile, undefined, undefined, { stackName: location + '/' }));
+        expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(workspace.devfile, undefined, namespace, { stackName: location + '/' }));
+      expect(setWorkspaceQualifiedName).toHaveBeenCalledWith(namespace, workspace.devfile.metadata.name);
 
       jest.runOnlyPendingTimers();
       expect(showAlertMock).not.toHaveBeenCalled();
@@ -165,7 +354,8 @@ describe('Factory Loader container', () => {
 
       jest.runOnlyPendingTimers();
       await waitFor(() =>
-        expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(workspace.devfile, undefined, undefined, { stackName: location + '/' }));
+        expect(createWorkspaceFromDevfileMock).toHaveBeenCalledWith(workspace.devfile, undefined, namespace, { stackName: location + '/' }));
+      expect(setWorkspaceQualifiedName).toHaveBeenCalledWith(namespace, workspace.devfile.metadata.name);
 
       jest.runOnlyPendingTimers();
       expect(showAlertMock).toBeCalledWith({
@@ -193,8 +383,8 @@ describe('Factory Loader container', () => {
       jest.runOnlyPendingTimers();
       await waitFor(() => expect(requestFactoryResolverMock).toHaveBeenCalledWith(
         location.split('&')[0], {
-          'override.metadata.generateName': 'testPrefix'
-        }));
+        'override.metadata.generateName': 'testPrefix'
+      }));
       expect(LoadFactorySteps[elementCurrentStep.innerHTML]).toEqual(LoadFactorySteps[LoadFactorySteps.APPLYING_DEVFILE]);
 
       jest.runOnlyPendingTimers();
@@ -206,7 +396,7 @@ describe('Factory Loader container', () => {
               name: 'name-wksp-2',
             },
             attributes: { persistVolumes: 'false' }
-          }, undefined, undefined,
+          }, undefined, namespace,
           { stackName: 'http://test-location/?override.metadata.generateName=testPrefix' }));
     });
 
@@ -285,7 +475,7 @@ describe('Factory Loader container', () => {
             metadata: {
               name: 'test-wksp-name',
             },
-          }, undefined, undefined, { stackName: location + '/' }));
+          }, undefined, namespace, { stackName: location + '/' }));
     });
 
     it('should resolve the factory with  the preferred storage type "ephemeral"', async () => {
@@ -309,7 +499,7 @@ describe('Factory Loader container', () => {
             attributes: {
               persistVolumes: 'false',
             },
-          }), undefined, undefined, { stackName: location + '/' }));
+          }), undefined, namespace, { stackName: location + '/' }));
     });
 
     it('should resolve the factory with  the preferred storage type "async"', async () => {
@@ -334,7 +524,7 @@ describe('Factory Loader container', () => {
               persistVolumes: 'false',
               asyncPersist: 'true',
             },
-          }), undefined, undefined, { stackName: location + '/' }));
+          }), undefined, namespace, { stackName: location + '/' }));
     });
 
     it('should show an error if something wrong with Repository/Devfile URL', async () => {
@@ -377,7 +567,7 @@ describe('Factory Loader container', () => {
       await waitFor(() => expect(createWorkspaceFromDevfileMock).not.toBeCalled());
     });
 
-    it('should resolve the factory with create policie "peruser" and create a new workspace', async () => {
+    it('should resolve the factory with create policy "peruser" and create a new workspace', async () => {
       const location = 'http://test2-location&policies.create=peruser';
       const name = 'test-name';
       const devWorkspace = new DevWorkspaceBuilder()
@@ -408,15 +598,16 @@ describe('Factory Loader container', () => {
                   'che.eclipse.org/devfile-source': safeDump({ factory: { params: 'url=http://test2-location&policies.create=peruser' } })
                 }
               }
-            }
+            },
+            components: [],
           }, undefined, undefined, {
-            factoryParams: 'url=http://test2-location&policies.create=peruser',
-            'policies.create': 'peruser'
-          }));
+          factoryParams: 'url=http://test2-location&policies.create=peruser',
+          'policies.create': 'peruser'
+        }));
     });
   });
 
-  it('should resolve the factory with create policie "perclick" and create a new workspace', async () => {
+  it('should resolve the factory with create policy "perclick" and create a new workspace', async () => {
     const location = 'http://test-location&policies.create=perclick';
     const devWorkspace = new DevWorkspaceBuilder()
       .withId('id-wksp-test')
@@ -441,10 +632,10 @@ describe('Factory Loader container', () => {
 
 function renderComponentV2(
   url: string,
-  workspace: IDevWorkspace,
+  workspace: devfileApi.DevWorkspace,
 ): RenderResult {
   const wrks = convertWorkspace(workspace);
-  (wrks.ref as IDevWorkspace).metadata.annotations = {
+  (wrks.ref as devfileApi.DevWorkspace).metadata.annotations = {
     'che.eclipse.org/devfile-source': safeDump({ factory: { params: 'url=http://test-location&policies.create=peruser' } })
   };
   const store = new FakeStoreBuilder()
@@ -452,7 +643,12 @@ function renderComponentV2(
       workspaces: [workspace],
     })
     .withWorkspaces({
-      workspaceId: workspace.status.devworkspaceId
+      workspaceId: WorkspaceAdapter.getId(workspace),
+      namespace: namespace,
+      workspaceName: workspace.metadata.name,
+    })
+    .withWorkspacesSettings({
+      'che.devworkspaces.enabled': 'true',
     })
     .withFactoryResolver({
       v: '4.0',
@@ -488,16 +684,19 @@ function renderComponentV1(
       workspaces: [workspace],
     })
     .withWorkspaces({
-      workspaceId: workspace.id
+      workspaceId: workspace.id,
+      namespace: namespace,
+      workspaceName: workspace.devfile.metadata.name
     })
     .withWorkspacesSettings(settings as che.WorkspaceSettings)
     .withFactoryResolver({
       v: '4.0',
       source: 'devfile.yaml',
-      devfile: workspace.devfile as api.che.workspace.devfile.Devfile,
+      devfile: workspace.devfile as che.WorkspaceDevfile,
       location: url.split('&')[0],
       links: []
     })
+    .withInfrastructureNamespace([{ name: namespace, attributes: { phase: 'Active' } }], false)
     .build();
   const props = getMockRouterProps(ROUTE.LOAD_FACTORY_URL, { url });
 
