@@ -15,10 +15,10 @@ import { fetchBranding } from '../../services/assets/branding';
 import { AppThunk } from '..';
 import { merge } from 'lodash';
 import axios from 'axios';
+import common from '@eclipse-che/common';
 import { BRANDING_DEFAULT, BrandingData } from '../../services/bootstrap/branding.constant';
 import { container } from '../../inversify.config';
-import { CheWorkspaceClient } from '../../services/workspace-client/cheWorkspaceClient';
-import { getErrorMessage } from '../../services/helpers/getErrorMessage';
+import { CheWorkspaceClient } from '../../services/workspace-client/cheworkspace/cheWorkspaceClient';
 import { createObject } from '../helpers';
 import { isSafari } from '../../services/helpers/detectBrowser';
 
@@ -74,7 +74,7 @@ export const actionCreators: ActionCreators = {
           data: branding,
         });
       } catch (e) {
-        const errorMessage = `Failed to fetch branding data by URL: "${url}", reason: ` + getErrorMessage(e);
+        const errorMessage = `Failed to fetch branding data by URL: "${url}", reason: ` + common.helpers.errors.getMessage(e);
         dispatch({
           type: 'RECEIVED_BRANDING_ERROR',
           error: errorMessage,
@@ -93,7 +93,7 @@ export const actionCreators: ActionCreators = {
             data: branding,
           });
         } catch (e) {
-          const errorMessage = 'OPTIONS request to "/api/" failed, reason: ' + getErrorMessage(e);
+          const errorMessage = 'OPTIONS request to "/api/" failed, reason: ' + common.helpers.errors.getMessage(e);
           dispatch({
             type: 'RECEIVED_BRANDING_ERROR',
             error: errorMessage,
@@ -137,7 +137,7 @@ export const reducer: Reducer<State> = (state: State | undefined, incomingAction
   }
 };
 
-async function getApiInfo(): Promise<{implementationVersion: string}> {
+async function getApiInfo(): Promise<{ implementationVersion: string }> {
   if (isSafari) {
     return (await axios.options('/api/')).data;
   }
