@@ -13,12 +13,12 @@
 import { Action, Reducer } from 'redux';
 import { RequestError } from '@eclipse-che/workspace-client';
 import axios, { AxiosResponse } from 'axios';
+import common from '@eclipse-che/common';
 import { FactoryResolver } from '../../services/helpers/types';
 import { container } from '../../inversify.config';
-import { CheWorkspaceClient } from '../../services/workspace-client/cheWorkspaceClient';
+import { CheWorkspaceClient } from '../../services/workspace-client/cheworkspace/cheWorkspaceClient';
 import { AppThunk } from '../index';
 import { createObject } from '../helpers';
-import { getErrorMessage } from '../../services/helpers/getErrorMessage';
 import { getDevfile } from './getDevfile';
 
 const WorkspaceClient = container.get(CheWorkspaceClient);
@@ -99,7 +99,7 @@ export async function grabLink(links: api.che.core.rest.Link, filename: string):
     return response.data;
   } catch (error) {
     // content may not be there
-    if (error.response.status == 404) {
+    if (common.helpers.errors.isAxiosError(error) && error.response?.status == 404) {
       return undefined;
     }
     throw error;
@@ -107,10 +107,15 @@ export async function grabLink(links: api.che.core.rest.Link, filename: string):
 }
 
 export const actionCreators: ActionCreators = {
-  requestFactoryResolver: (location: string, overrideParams?: { [params: string]: string }): AppThunk<KnownAction, Promise<void>> => async (dispatch): Promise<void> => {
+
+  requestFactoryResolver: (location: string, overrideParams?: { [params: string]: string }): AppThunk<KnownAction, Promise<void>> => async (dispatch, getState): Promise<void> => {
     dispatch({ type: 'REQUEST_FACTORY_RESOLVER' });
 
+    const state = getState();
+
     try {
+
+      await WorkspaceClient.restApiClient.provisionKubernetesNamespace();
       const data = await WorkspaceClient.restApiClient.getFactoryResolver<FactoryResolver>(location, overrideParams);
       if (!data.devfile) {
         throw 'The specified link does not contain a valid Devfile.';
@@ -125,11 +130,12 @@ export const actionCreators: ActionCreators = {
       if (cheTheiaPlugins) {
         optionalFilesContent['.che/che-theia-plugins.yaml'] = cheTheiaPlugins;
       }
-      const cheEditor = await grabLink(data.links, 'che editor file');
+      const cheEditor = await grabLink(data.links, '.che/che-editor.yaml');
       if (cheEditor) {
         optionalFilesContent['.che/che-editor.yaml'] = cheEditor;
       }
       const devfile = getDevfile(data, location);
+
       const { source, scm_info } = data;
       dispatch({
         type: 'RECEIVE_FACTORY_RESOLVER',
@@ -143,7 +149,7 @@ export const actionCreators: ActionCreators = {
       if (response.status === 401 && isOAuthResponse(responseData)) {
         throw responseData;
       }
-      const errorMessage = 'Failed to request factory resolver: ' + getErrorMessage(e);
+      const errorMessage = 'Failed to request factory resolver: ' + common.helpers.errors.getMessage(e);
       dispatch({
         type: 'RECEIVE_FACTORY_RESOLVER_ERROR',
         error: errorMessage,
