@@ -11,10 +11,10 @@
  */
 
 import { Action, Reducer } from 'redux';
+import common from '@eclipse-che/common';
 import { container } from '../../inversify.config';
-import { CheWorkspaceClient } from '../../services/workspace-client/cheWorkspaceClient';
+import { CheWorkspaceClient } from '../../services/workspace-client/cheworkspace/cheWorkspaceClient';
 import { AppThunk } from '..';
-import { getErrorMessage } from '../../services/helpers/getErrorMessage';
 import { createObject } from '../helpers';
 
 const WorkspaceClient = container.get(CheWorkspaceClient);
@@ -53,6 +53,7 @@ export const actionCreators: ActionCreators = {
     dispatch({ type: 'REQUEST_NAMESPACES' });
 
     try {
+      await WorkspaceClient.restApiClient.provisionKubernetesNamespace();
       const namespaces = await WorkspaceClient.restApiClient.getKubernetesNamespace<Array<che.KubernetesNamespace>>();
       dispatch({
         type: 'RECEIVE_NAMESPACES',
@@ -60,7 +61,7 @@ export const actionCreators: ActionCreators = {
       });
       return namespaces;
     } catch (e) {
-      const errorMessage = 'Failed to fetch list of available kubernetes namespaces, reason: ' + getErrorMessage(e);
+      const errorMessage = 'Failed to fetch list of available kubernetes namespaces, reason: ' + common.helpers.errors.getMessage(e);
       dispatch({
         type: 'RECEIVE_NAMESPACES_ERROR',
         error: errorMessage,
