@@ -11,11 +11,11 @@
  */
 
 import { Action, Reducer } from 'redux';
+import common from '@eclipse-che/common';
 import { createObject } from '../helpers';
 import { AppThunk } from '../index';
 import { container } from '../../inversify.config';
-import { CheWorkspaceClient } from '../../services/workspace-client/cheWorkspaceClient';
-import { getErrorMessage } from '../../services/helpers/getErrorMessage';
+import { CheWorkspaceClient } from '../../services/workspace-client/cheworkspace/cheWorkspaceClient';
 
 const WorkspaceClient = container.get(CheWorkspaceClient);
 
@@ -66,7 +66,7 @@ export const actionCreators: ActionCreators = {
       });
       return;
     } catch (e) {
-      const errorMessage = 'Failed to fetch currently logged user info, reason: ' + getErrorMessage(e);
+      const errorMessage = 'Failed to fetch currently logged user info, reason: ' + common.helpers.errors.getMessage(e);
       dispatch({
         type: 'RECEIVE_USER_ERROR',
         error: errorMessage,
