@@ -13,14 +13,11 @@
 import { Reducer } from 'redux';
 import { AppThunk } from '..';
 import { createObject } from '../helpers';
-import { IDevWorkspace, IDevWorkspaceDevfile } from '@eclipse-che/devworkspace-client';
+import devfileApi, { isDevfileV2, isDevWorkspace } from '../../services/devfileApi';
 import {
-  convertWorkspace,
-  isWorkspaceV2,
-  isDevfileV2,
   Workspace,
-  isWorkspaceV1,
-} from '../../services/workspaceAdapter';
+  isCheWorkspace,
+} from '../../services/workspace-adapter';
 import * as CheWorkspacesStore from './cheWorkspaces';
 import * as DevWorkspacesStore from './devWorkspaces';
 
@@ -111,14 +108,14 @@ export type ActionCreators = {
   deleteWorkspace: (workspace: Workspace) => AppThunk<KnownAction, Promise<void>>;
   updateWorkspace: (workspace: Workspace) => AppThunk<KnownAction, Promise<void>>;
   createWorkspaceFromDevfile: (
-    devfile: che.WorkspaceDevfile | IDevWorkspaceDevfile,
+    devfile: che.WorkspaceDevfile | devfileApi.Devfile,
     namespace: string | undefined,
     infrastructureNamespace: string | undefined,
-    attributes: { [key: string]: string } | {},
+    attributes: { [key: string]: string },
     optionalFilesContent?: {
       [fileName: string]: string
     }
-  ) => AppThunk<KnownAction, Promise<Workspace>>;
+  ) => AppThunk<KnownAction, Promise<void>>;
 
   setWorkspaceQualifiedName: (namespace: string, workspaceName: string) => AppThunk<SetWorkspaceQualifiedName>;
   clearWorkspaceQualifiedName: () => AppThunk<ClearWorkspaceQualifiedName>;
@@ -159,7 +156,7 @@ export const actionCreators: ActionCreators = {
       const state = getState();
       const cheDevworkspaceEnabled = state.workspacesSettings.settings['che.devworkspaces.enabled'] === 'true';
 
-      if (cheDevworkspaceEnabled && isWorkspaceV2(workspace.ref)) {
+      if (cheDevworkspaceEnabled && isDevWorkspace(workspace.ref)) {
         await dispatch(DevWorkspacesStore.actionCreators.requestWorkspace(workspace.ref));
       } else {
         await dispatch(CheWorkspacesStore.actionCreators.requestWorkspace(workspace.ref as che.Workspace));
@@ -177,10 +174,11 @@ export const actionCreators: ActionCreators = {
       const state = getState();
       const cheDevworkspaceEnabled = state.workspacesSettings.settings['che.devworkspaces.enabled'] === 'true';
 
-      if (cheDevworkspaceEnabled && isWorkspaceV2(workspace.ref)) {
-        await dispatch(DevWorkspacesStore.actionCreators.startWorkspace(workspace.ref));
+      if (cheDevworkspaceEnabled && isDevWorkspace(workspace.ref)) {
+        const debugWorkspace = params && params['debug-workspace-start'];
+        await dispatch(DevWorkspacesStore.actionCreators.startWorkspace(workspace.ref, debugWorkspace));
       } else {
-        await dispatch(CheWorkspacesStore.actionCreators.startWorkspace(workspace as che.Workspace, params));
+        await dispatch(CheWorkspacesStore.actionCreators.startWorkspace(workspace.ref as che.Workspace, params));
       }
       dispatch({ type: 'UPDATE_WORKSPACE' });
     } catch (e) {
@@ -193,7 +191,7 @@ export const actionCreators: ActionCreators = {
     try {
       const state = getState();
       const cheDevworkspaceEnabled = state.workspacesSettings.settings['che.devworkspaces.enabled'] === 'true';
-      if (cheDevworkspaceEnabled && isWorkspaceV2(workspace.ref)) {
+      if (cheDevworkspaceEnabled && isDevWorkspace(workspace.ref)) {
         await dispatch(DevWorkspacesStore.actionCreators.restartWorkspace(workspace.ref));
       } else {
         await dispatch(CheWorkspacesStore.actionCreators.restartWorkspace(workspace.ref as che.Workspace));
@@ -208,7 +206,7 @@ export const actionCreators: ActionCreators = {
     try {
       const state = getState();
       const cheDevworkspaceEnabled = state.workspacesSettings.settings['che.devworkspaces.enabled'] === 'true';
-      if (cheDevworkspaceEnabled && isWorkspaceV2(workspace.ref)) {
+      if (cheDevworkspaceEnabled && isDevWorkspace(workspace.ref)) {
         await dispatch(DevWorkspacesStore.actionCreators.stopWorkspace(workspace.ref));
       } else {
         await dispatch(CheWorkspacesStore.actionCreators.stopWorkspace(workspace.ref as che.Workspace));
@@ -224,7 +222,7 @@ export const actionCreators: ActionCreators = {
     try {
       const state = getState();
       const cheDevworkspaceEnabled = state.workspacesSettings.settings['che.devworkspaces.enabled'] === 'true';
-      if (cheDevworkspaceEnabled && isWorkspaceV2(workspace.ref)) {
+      if (cheDevworkspaceEnabled && isDevWorkspace(workspace.ref)) {
         await dispatch(DevWorkspacesStore.actionCreators.terminateWorkspace(workspace.ref));
       } else {
         await dispatch(CheWorkspacesStore.actionCreators.deleteWorkspace(workspace.ref as che.Workspace));
@@ -238,10 +236,10 @@ export const actionCreators: ActionCreators = {
   updateWorkspace: (workspace: Workspace): AppThunk<KnownAction, Promise<void>> => async (dispatch): Promise<void> => {
     dispatch({ type: 'REQUEST_WORKSPACES' });
     try {
-      if (isWorkspaceV1(workspace.ref)) {
+      if (isCheWorkspace(workspace.ref)) {
         await dispatch(CheWorkspacesStore.actionCreators.updateWorkspace(workspace.ref as che.Workspace));
       } else {
-        await dispatch(DevWorkspacesStore.actionCreators.updateWorkspace(workspace.ref as IDevWorkspace));
+        await dispatch(DevWorkspacesStore.actionCreators.updateWorkspace(workspace.ref as devfileApi.DevWorkspace));
       }
       dispatch({ type: 'UPDATE_WORKSPACE' });
     } catch (e) {
@@ -251,14 +249,14 @@ export const actionCreators: ActionCreators = {
   },
 
   createWorkspaceFromDevfile: (
-    devfile: che.WorkspaceDevfile | IDevWorkspaceDevfile,
+    devfile: che.WorkspaceDevfile | devfileApi.Devfile,
     namespace: string | undefined,
     infrastructureNamespace: string | undefined,
-    attributes: { [key: string]: string } = {},
+    attributes: { [key: string]: string },
     optionalFilesContent?: {
       [fileName: string]: string
     }
-  ): AppThunk<KnownAction, Promise<Workspace>> => async (dispatch, getState): Promise<Workspace> => {
+  ): AppThunk<KnownAction, Promise<void>> => async (dispatch, getState): Promise<void> => {
     dispatch({ type: 'REQUEST_WORKSPACES' });
     try {
       const state = getState();
@@ -267,15 +265,13 @@ export const actionCreators: ActionCreators = {
       if (cheDevworkspaceEnabled && isDevfileV2(devfile)) {
         const pluginRegistryUrl = state.workspacesSettings.settings['cheWorkspacePluginRegistryUrl'];
         const pluginRegistryInternalUrl = state.workspacesSettings.settings['cheWorkspacePluginRegistryInternalUrl'];
-        const devWorkspace = await dispatch(DevWorkspacesStore.actionCreators.createWorkspaceFromDevfile(devfile, optionalFilesContent || {}, pluginRegistryUrl, pluginRegistryInternalUrl));
+        await dispatch(DevWorkspacesStore.actionCreators.createWorkspaceFromDevfile(devfile, optionalFilesContent || {}, pluginRegistryUrl, pluginRegistryInternalUrl, attributes));
         dispatch({ type: 'ADD_WORKSPACE' });
-        return convertWorkspace(devWorkspace);
       } else {
-        const cheWorkspace = await dispatch(CheWorkspacesStore.actionCreators.createWorkspaceFromDevfile(devfile as che.WorkspaceDevfile, namespace, infrastructureNamespace, attributes));
+        await dispatch(CheWorkspacesStore.actionCreators.createWorkspaceFromDevfile(devfile as che.WorkspaceDevfile, namespace, infrastructureNamespace, attributes));
         dispatch({
           type: 'ADD_WORKSPACE',
         });
-        return convertWorkspace(cheWorkspace);
       }
     } catch (e) {
       dispatch({ type: 'RECEIVE_ERROR' });
